@@ -1,40 +1,34 @@
 package ParseUtil::Domain;
 
-use strict;
-use warnings;
 
 ## no critic
-our $VERSION = '2.26';
+our $VERSION = '2.27';
 $VERSION = eval $VERSION;
 ## use critic
 
+use perl5i::2;
+
 use Perl6::Export::Attrs;
 use ParseUtil::Domain::ConfigData;
 use Net::IDN::Encode ':all';
 use Net::IDN::Punycode ':all';
 use Net::IDN::Nameprep;
-use List::MoreUtils qw/any/;
-use Carp;
-
-use feature 'switch';
 
 #use Smart::Comments;
-#use YAML;
-use utf8;
 
-sub parse_domain : Export(:parse) {
-    my $name = shift;
+func parse_domain($name) :Export(:parse) {
     $name =~ s/\s//gs;
-    open my $utf8h, "<:encoding(utf8)", \$name;
+    open my $utf8h, "<", \$name;
     my $utf8_name = do { local $/; <$utf8h>; };
-    close $utf8h;
-    my @name_segments = split /\Q@\E/, $utf8_name;
+    $utf8h->close;
+    my @name_segments = $utf8_name->split(qr{\Q@\E});
     ### namesegments : Dump(\@name_segments)
 
-    my @segments = split /[\.\x{FF0E}\x{3002}\x{FF61}]/, $name_segments[-1];
+    my @segments = $name_segments[-1]->split(qr/[\.\x{FF0E}\x{3002}\x{FF61}]/);
     ### executing with : $name
     my ( $zone, $zone_ace, $domain_segments ) =
-      @{ _find_zone( \@segments ) }{qw/zone zone_ace domain/};
+      _find_zone( \@segments )->slice(qw/zone zone_ace domain/);
+
     ### found zone : $zone
     ### found zone_ace : $zone_ace
 
@@ -45,20 +39,21 @@ sub parse_domain : Export(:parse) {
     if ( @name_segments > 1 ) {
         my $punycoded_name = _punycode_segments( [ $name_segments[0] ], $zone );
         my ( $name_domain, $name_ace ) =
-          @{$punycoded_name}{qw/domain domain_ace/};
-        $puny_processed->{domain} = join '@' => $name_domain,
-          $puny_processed->{domain};
+          $punycoded_name->slice(qw/domain domain_ace/);
+
+        $puny_processed->{domain} =
+          [ $name_domain, $puny_processed->{domain} ]->join('@');
         if ($name_ace) {
-            $puny_processed->{domain_ace} = join '@' => $name_ace,
-              $puny_processed->{domain_ace};
+            $puny_processed->{domain_ace} =
+              [ $name_ace, $puny_processed->{domain_ace} ]->join('@');
+
         }
     }
     return $puny_processed;
 
 }
 
-sub puny_convert : Export(:simple) {
-    my $domain = shift;
+func puny_convert($domain) :Export(:simple) {
     my @keys;
     given ($domain) {
         when (/\.?xn--/) {
@@ -68,18 +63,18 @@ sub puny_convert : Export(:simple) {
             @keys = qw/domain_ace zone_ace/;
         }
     }
-    my $parsed = parse_domain($domain);
-    my $parsed_domain = join "." => @{$parsed}{@keys};
+    my $parsed        = parse_domain($domain);
+    my $parsed_domain = $parsed->slice(@keys)->join(".");
 
     return $parsed_domain;
 }
 
-sub _find_zone {
-    my $domain_segments = shift;
-    my $tld_regex       = ParseUtil::Domain::ConfigData->config('tld_regex');
-    my $tld             = pop @{$domain_segments};
-    my $sld             = pop @{$domain_segments};
-    my $thld            = pop @{$domain_segments};
+func _find_zone($domain_segments) {
+
+    my $tld_regex = ParseUtil::Domain::ConfigData->config('tld_regex');
+    my $tld       = $domain_segments->pop;
+    my $sld       = $domain_segments->pop;
+    my $thld      = $domain_segments->pop;
 
     my ( $possible_tld, $possible_thld );
     my ( $sld_zone_ace, $tld_zone_ace ) =
@@ -124,8 +119,7 @@ sub _find_zone {
     };
 }
 
-sub _punycode_segments {
-    my ( $domain_segments, $zone ) = @_;
+func _punycode_segments( $domain_segments, $zone ) {
     if ( not $zone or $zone !~ /^(?:de|fr|pm|re|tf|wf|yt)$/ ) {
         my $puny_encoded = [];
         foreach my $segment ( @{$domain_segments} ) {
@@ -139,26 +133,24 @@ sub _punycode_segments {
         }
         my $puny_decoded = [ map { domain_to_unicode($_) } @{$puny_encoded} ];
         croak "Undefined mapping!"
-          if any { lc $_ ne nameprep( lc $_ ) } @{$puny_decoded};
+          if $puny_decoded->any( sub { lc $_ ne nameprep( lc $_ ) } );
         return {
-            domain     => ( join "." => @{$puny_decoded} ),
-            domain_ace => ( join "." => @{$puny_encoded} )
+            domain     => $puny_decoded->join("."),
+            domain_ace => $puny_encoded->join(".")
         };
     }
 
-    # Have to avoid the nameprep step for .de domains now that DENIC has
-    # decided to allow the German "sharp S".
+    # Avoid nameprep step for certain tlds
     my $puny_encoded = [ map { _puny_encode( lc $_ ) } @{$domain_segments} ];
     my $puny_decoded = [ map { _puny_decode($_) } @{$puny_encoded} ];
     return {
-        domain     => ( join "." => @{$puny_decoded} ),
-        domain_ace => ( join "." => @{$puny_encoded} )
+        domain     => $puny_decoded->join("."),
+        domain_ace => $puny_encoded->join(".")
     };
-
 }
 
-sub _puny_encode {
-    my $unencoded = shift;
+func _puny_encode($unencoded) {
+
     ### encoding : $unencoded
     # quick check to make sure that domain should be decoded
     my $temp_unencoded = nameprep $unencoded;
@@ -168,9 +160,9 @@ sub _puny_encode {
     return "xn--" . encode_punycode($unencoded);
 }
 
-sub _puny_decode {
-    my $encoded = shift;
-    return $encoded unless $encoded =~ /xn--/;
+func _puny_decode($encoded) {
+    return $encoded
+      unless $encoded =~ /xn--/;
     $encoded =~ s/^xn--//;
     ### decoding : $encoded
     my $test_decode = decode_punycode($encoded);
@@ -180,7 +172,6 @@ sub _puny_decode {
 
 }
 
-"one, but we're not the same";
 
 __END__
 
@@ -209,13 +200,12 @@ ParseUtil::Domain - Domain parser and puny encoder/decoder.
 
 
 This purpose of this module is to parse a domain name into its respective name and tld. Note that
-the I<tld> may actually refer to a second or third level domain (i.e. co.uk or
-plc.co.im).  It also provides respective puny encoded and decoded versions of
+the I<tld> may actually refer to a second- or third-level domain, e.g. co.uk or
+plc.co.im.  It also provides respective puny encoded and decoded versions of
 the parsed domain.
 
-This module makes use of the data provided by the I<Public Suffix List>
-(L<http://publicsuffix.org/list/>) to parse tlds.
-
+This module uses TLD data from the L<Public Suffix List|http://publicsuffix.org/list/> which is included with this
+distribution.
 
 
 =head1 INTERFACE
@@ -318,7 +308,7 @@ L<Regexp::Assemble::Compressed>
 
 
 =item
-The Public Suffix List at L<http://publicsuffix.org/list/>.
+The L<Public Suffix List|http://publicsuffix.org/list/>.
 
 
 =back
@@ -331,11 +321,13 @@ The Public Suffix List at L<http://publicsuffix.org/list/>.
 
 
 =item *
-Updated public suffix list.
+Updated with latest version of the public suffix list.
 
 =item *
 Added a bunch of new TLDs (nTLDs).
 
+=item *
+Now uses L<perl5i>.
 
 
 =back
